# datatime

![Tests](https://github.com/fspinna/datatime/actions/workflows/tests.yml/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/datatime/badge/?version=latest)](https://datatime.readthedocs.io/en/latest/?badge=latest)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## How to install
```bash
pip install git+https://github.com/fspinna/datatime.git
```

## References
### [UEA & UCR Time Series Classification Repository](https://www.timeseriesclassification.com/)
A. Bagnall, J. Lines, W. Vickers and E. Keogh, The UEA & UCR Time Series Classification Repository, www.timeseriesclassification.com

### [Monash, UEA & UCR Time Series Extrinsic Regression Repository](http://tseregression.org/)
Chang Wei Tan, Christoph Bergmeir, Francois Petitjean, & Geoffrey I Webb. (2020). Monash, UEA & UCR Time Series Regression Datasets [Data set]. Zenodo. https://doi.org/10.5281/zenodo.4632512

### [Monash Time Series Forecasting Repository](https://forecastingdata.org/)
Godahewa, R., Bergmeir, C., Webb, G. I., Hyndman, R. J., & Montero-Manso, P. (2021). Monash time series forecasting archive. arXiv preprint arXiv:2105.06643.

### [The Ryerson Audio-Visual Database of Emotional Speech and Song (RAVDESS)](https://zenodo.org/record/1188976)
Livingstone SR, Russo FA (2018) The Ryerson Audio-Visual Database of Emotional Speech and Song (RAVDESS): A dynamic, multimodal set of facial and vocal expressions in North American English. PLoS ONE 13(5): e0196391.


